@@ -31,24 +31,25 @@
 #' @param chunk_size size of chunk of (input) data in bytes
 #' @param skipped_columns a list of column indices to be excluded from parsing
 #' @param custom_non_data_line_markers (Optional) If a line in imported file starts with any character in given string it will NOT be imported. Empty string means all lines are imported, NULL means that default behaviour for given format will be used
+#' @param partition_by (Optional) Names of the columns the persisted dataset has been partitioned by.
 #' @seealso \link{h2o.importFile}, \link{h2o.parseSetup}
 #' @export
 h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, sep = "", col.names=NULL,
                          col.types=NULL, na.strings=NULL, blocking=FALSE, parse_type = NULL, chunk_size = NULL,
-                         decrypt_tool = NULL, skipped_columns = NULL, custom_non_data_line_markers = NULL) {
+                         decrypt_tool = NULL, skipped_columns = NULL, custom_non_data_line_markers = NULL, partition_by=NULL) {
   # Check and parse col.types in case col.types is supplied col.name = col.type vec
   if( length(names(col.types)) > 0 & typeof(col.types) != "list" ) {
     parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types = NULL,
                                    na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size,
                                    decrypt_tool = decrypt_tool, skipped_columns=skipped_columns,
-                                   custom_non_data_line_markers = custom_non_data_line_markers)
+                                   custom_non_data_line_markers = custom_non_data_line_markers, partition_by = partition_by)
     idx = match(names(col.types), parse.params$column_names)
     parse.params$column_types[idx] = as.character(col.types)
   } else {
     parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types,
                                    na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size,
                                    decrypt_tool = decrypt_tool, skipped_columns=skipped_columns,
-                                   custom_non_data_line_markers = custom_non_data_line_markers)
+                                   custom_non_data_line_markers = custom_non_data_line_markers, partition_by = partition_by)
   }
   for(w in parse.params$warnings){
     cat('WARNING:',w,'\n')
@@ -68,7 +69,8 @@ h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, se
             delete_on_done = parse.params$delete_on_done,
             blocking = blocking,
             decrypt_tool = .decrypt_tool_id(parse.params$decrypt_tool),
-            skipped_columns = paste0("[", paste(parse.params$skipped_columns, collapse=','), "]")
+            skipped_columns = paste0("[", paste(parse.params$skipped_columns, collapse=','), "]"),
+            partition_by = .collapse.array(parse.params$partition_by)
             )
   if(!is.null(custom_non_data_line_markers)){
     parse.params <- append(parse.params,list(custom_non_data_line_markers = custom_non_data_line_markers))
@@ -134,7 +136,7 @@ h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, se
 #' @export
 h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA, sep = "", col.names = NULL, col.types = NULL,
                            na.strings = NULL, parse_type = NULL, chunk_size = NULL, decrypt_tool = NULL, skipped_columns = NULL,
-                           custom_non_data_line_markers = NULL) {
+                           custom_non_data_line_markers = NULL, partition_by=NULL) {
 
   # Allow single frame or list of frames; turn singleton into a list
   if( is.H2OFrame(data) ) data <- list(data)
@@ -151,6 +153,10 @@ h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA
   if(!is.null(custom_non_data_line_markers)) {
     parseSetup.params$custom_non_data_line_markers = custom_non_data_line_markers
   }
+  
+  if(!is.null(partition_by)) {
+    parseSetup.params$partition_by <- paste0("[", paste (partition_by, collapse = ','), "]")
+  }
 
   if (!is.null(skipped_columns)) {
     skipped_columns = sort(skipped_columns)
@@ -279,7 +285,8 @@ h2o.parseSetup <- function(data, pattern="", destination_frame = "", header = NA
         warnings           = parseSetup$warnings,
         decrypt_tool       = parseSetup$decrypt_tool,
         skipped_columns    = parseSetup$skipped_columns,
-        custom_non_data_line_markers = parseSetup$custom_non_data_line_markers
+        custom_non_data_line_markers = parseSetup$custom_non_data_line_markers,
+        partition_by       = parseSetup$partition_by
         )
 }
 
